pub struct EqualityIndex { /* private fields */ }Expand description
Index for equality lookups (namespace, source, project_id, etc.)
Implementations
Sourceimpl EqualityIndex
impl EqualityIndex
Sourcepub fn add_string(&mut self, value: &str, doc_id: u64)
pub fn add_string(&mut self, value: &str, doc_id: u64)
Add a document with a string value
Sourcepub fn add_uint(&mut self, value: u64, doc_id: u64)
pub fn add_uint(&mut self, value: u64, doc_id: u64)
Add a document with an unsigned integer value
Sourcepub fn remove_string(&mut self, value: &str, doc_id: u64)
pub fn remove_string(&mut self, value: &str, doc_id: u64)
Remove a document with a string value
Sourcepub fn lookup_string(&self, value: &str) -> AllowedSet
pub fn lookup_string(&self, value: &str) -> AllowedSet
Lookup documents with a string value
Sourcepub fn lookup_int(&self, value: i64) -> AllowedSet
pub fn lookup_int(&self, value: i64) -> AllowedSet
Lookup documents with an integer value
Sourcepub fn lookup_uint(&self, value: u64) -> AllowedSet
pub fn lookup_uint(&self, value: u64) -> AllowedSet
Lookup documents with a uint value
Sourcepub fn lookup_string_in(&self, values: &[String]) -> AllowedSet
pub fn lookup_string_in(&self, values: &[String]) -> AllowedSet
Lookup documents in a set of string values (OR)
Sourcepub fn lookup_uint_in(&self, values: &[u64]) -> AllowedSet
pub fn lookup_uint_in(&self, values: &[u64]) -> AllowedSet
Lookup documents in a set of uint values (OR)
Sourcepub fn string_values(&self) -> impl Iterator<Item = &str>
pub fn string_values(&self) -> impl Iterator<Item = &str>
Get all unique values for this field
Sourcepub fn stats(&self) -> EqualityIndexStats
pub fn stats(&self) -> EqualityIndexStats
Get statistics