pub struct QualifiedTable {
pub namespace: String,
pub database: String,
pub table: String,
}Expand description
A fully qualified table path: namespace/database/table.
Used to address tables unambiguously across the entire hierarchy.
Fields
namespace: Stringdatabase: Stringtable: StringImplementations
Sourceimpl QualifiedTable
impl QualifiedTable
Sourcepub fn new(
namespace: impl Into<String>,
database: impl Into<String>,
table: impl Into<String>,
) -> Self
pub fn new( namespace: impl Into<String>, database: impl Into<String>, table: impl Into<String>, ) -> Self
Create a new qualified table path.
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Return the fully qualified name: namespace/database/table
Sourcepub fn storage_prefix(&self) -> String
pub fn storage_prefix(&self) -> String
Return the storage key prefix for this table. All row keys under this table are prefixed with this string.