PlanCache

Struct PlanCache 

pub struct PlanCache { /* private fields */ }
Query plan cache for repeated queries

Task 5 Enhancement: Frequency-Gated Caching

Plans are only cached after being used 3+ times to avoid polluting the cache with one-off queries.

Implementations

Source

impl PlanCache

pub fn new(max_entries: usize) -> Self

Create a new plan cache with default threshold (3)

pub fn with_threshold(max_entries: usize, cache_threshold: usize) -> Self

Create with custom frequency threshold

pub fn hash_query(query: &str) -> u64

Hash a query for caching

pub fn get(&mut self, query_hash: u64) -> Option<&ExecutionPlan>

Get cached plan with frequency tracking

Returns cached plan if available, or None. If query is seen frequently but not cached, attempts promotion.

pub fn put(&mut self, query_hash: u64, plan: ExecutionPlan)

Register a plan for potential caching

Does not immediately cache - waits for frequency threshold.

pub fn force_put(&mut self, query_hash: u64, plan: ExecutionPlan)

Force-cache a plan (bypasses frequency check)

pub fn clear(&mut self)

Clear the cache

pub fn stats(&self) -> CacheStats

Get cache statistics (legacy compatibility)

pub fn adaptive_stats(&self) -> &AdaptiveCacheStats

Get enhanced statistics