SqlBridge

Struct SqlBridge 

pub struct SqlBridge<C: SqlConnection> { /* private fields */ }
Unified SQL executor that routes through AST

Implementations

Source

impl<C: SqlConnection> SqlBridge<C>

pub fn new(conn: C) -> Self

Create a new SQL bridge with the given connection

pub fn get_scope(&self, name: &str) -> Option<&ScopeDefinition>

Get a scope definition by name.

pub fn get_table_permissions( &self, table: &str, ) -> Option<&StoredTablePermissions>

Get the table permission rules for a table.

pub fn check_table_permission( &self, table: &str, op: PermissionOp, ) -> SqlResult<()>

Check if the given operation is permitted on the table. If no permissions are defined for the table, all operations are allowed. Returns Ok(()) if allowed, Err if denied.

pub fn execute(&mut self, sql: &str) -> SqlResult<ExecutionResult>

Execute a SQL statement

pub fn execute_with_params( &mut self, sql: &str, params: &[SochValue], ) -> SqlResult<ExecutionResult>

Execute a SQL statement with parameters

pub fn execute_statement( &mut self, stmt: &Statement, params: &[SochValue], ) -> SqlResult<ExecutionResult>

Execute a parsed statement