TokenKind

Enum TokenKind 

pub enum TokenKind<'a> {
Show 176 variants Integer(i64), Float(f64), String(Cow<'a, str>), Blob(Vec<u8>), Null, True, False, Identifier(&'a str), QuotedIdentifier(Cow<'a, str>), Create, Table, Index, Drop, Alter, Add, Column, Rename, To, Cascade, Primary, Key, Foreign, References, Unique, Default, AutoIncrement, If, Exists, Ignore, Replace, Conflict, Do, Nothing, Duplicate, Abort, Fail, Returning, Select, Insert, Update, Delete, Into, Values, Set, From, Where, Join, Inner, Left, Right, Outer, Cross, On, Using, As, Distinct, All, Group, Having, Order, By, Asc, Desc, Nulls, First, Last, Limit, Offset, Union, Intersect, Except, And, Or, Not, Is, In, Like, Escape, Between, Case, When, Then, Else, End, Cast, Collate, Begin, Commit, Rollback, Transaction, Savepoint, Release, Int, IntegerKw, Bigint, Smallint, Tinyint, FloatKw, Double, Real, Decimal, Numeric, Varchar, Char, Text, BlobKw, Boolean, Bool, Date, Time, Timestamp, Datetime, Count, Sum, Avg, Min, Max, Vector, VectorSearch, JsonExtract, JsonSet, ContextWindow, Embedding, Cosine, Euclidean, DotProduct, Relate, Live, Content, Event, Diff, Define, Scope, Remove, Session, Signin, Signup, Permissions, For, Plus, Minus, Star, Slash, Percent, Eq, Ne, Lt, Le, Gt, Ge, Concat, BitAnd, BitOr, BitNot, LeftShift, RightShift, LParen, RParen, LBracket, RBracket, Comma, Semicolon, Dot, Colon, DoubleColon, Arrow, DoubleArrow, LeftArrow, BiArrow, QuestionMark, At, Placeholder(u32), Comment(&'a str), Whitespace, Eof, Invalid(&'a str),
}
Token classification

Variants



Integer(i64)



Float(f64)



String(Cow<'a, str>)



Blob(Vec<u8>)



Null



True



False



Identifier(&'a str)



QuotedIdentifier(Cow<'a, str>)



Create



Table



Index



Drop



Alter



Add



Column



Rename



To



Cascade



Primary



Key



Foreign



References



Unique



Default



AutoIncrement



If



Exists



Ignore



Replace



Conflict



Do



Nothing



Duplicate



Abort



Fail



Returning



Select



Insert



Update



Delete



Into



Values



Set



From



Where



Join



Inner



Left



Right



Outer



Cross



On



Using



As



Distinct



All



Group



Having



Order



By



Asc



Desc



Nulls



First



Last



Limit



Offset



Union



Intersect



Except



And



Or



Not



Is



In



Like



Escape



Between



Case



When



Then



Else



End



Cast



Collate



Begin



Commit



Rollback



Transaction



Savepoint



Release



Int



IntegerKw



Bigint



Smallint



Tinyint



FloatKw



Double



Real



Decimal



Numeric



Varchar



Char



Text



BlobKw



Boolean



Bool



Date



Time



Timestamp



Datetime



Count



Sum



Avg



Min



Max



Vector



VectorSearch



JsonExtract



JsonSet



ContextWindow



Embedding



Cosine



Euclidean



DotProduct



Relate



Live



Content



Event



Diff



Define



Scope



Remove



Session



Signin



Signup



Permissions



For



Plus



Minus



Star



Slash



Percent



Eq



Ne



Lt



Le



Gt



Ge



Concat



BitAnd



BitOr



BitNot



LeftShift



RightShift



LParen



RParen



LBracket



RBracket



Comma



Semicolon



Dot



Colon



DoubleColon



Arrow



DoubleArrow



LeftArrow



BiArrow



QuestionMark



At



Placeholder(u32)



Comment(&'a str)



Whitespace



Eof



Invalid(&'a str)

Implementations

Source

impl<'a> TokenKind<'a>

pub fn is_keyword(&self) -> bool

Check if this token is a keyword

pub fn from_keyword(s: &str) -> Option<TokenKind<'a>>

Get keyword from string (case-insensitive) Uses a stack-allocated buffer to avoid heap allocation.