pub struct IndexAwareTopK<T, F>{ /* private fields */ }Expand description
Top-K with index awareness
When the index only partially matches the ORDER BY (e.g., index on col1 but ORDER BY col1, col2), we can still use the index for the first column and apply top-K for the rest.
Implementations
Sourceimpl<T, F> IndexAwareTopK<T, F>
impl<T, F> IndexAwareTopK<T, F>
Sourcepub fn push(&mut self, item: T, same_index_key_as_previous: bool)
pub fn push(&mut self, item: T, same_index_key_as_previous: bool)
Process an item from an index-ordered scan
Items must be provided in index order. When the index key changes, the previous batch is finalized.
Sourcepub fn is_complete(&self) -> bool
pub fn is_complete(&self) -> bool
Check if we have enough results
Sourcepub fn into_result(self) -> Vec<T>
pub fn into_result(self) -> Vec<T>
Drain into final result