pub struct Namespace(/* private fields */);Expand description
A validated namespace identifier
This is an opaque type that can only be constructed via validation, preventing accidental use of invalid namespace strings.
Implementations
Sourceimpl Namespace
impl Namespace
Sourcepub const MAX_LENGTH: usize = 256
pub const MAX_LENGTH: usize = 256
Maximum length for a namespace identifier
Sourcepub fn new(name: impl Into<String>) -> Result<Self, NamespaceError>
pub fn new(name: impl Into<String>) -> Result<Self, NamespaceError>
Create a new namespace (validates format)
Validation Rules
- Non-empty
- Max 256 characters
- Alphanumeric, underscores, hyphens, and periods only
- Cannot start with a period or hyphen
Sourcepub fn validate_name(name: &str) -> Result<(), NamespaceError>
pub fn validate_name(name: &str) -> Result<(), NamespaceError>
Validate a name string (public, reusable for database/table names too)
Sourcepub fn into_string(self) -> String
pub fn into_string(self) -> String
Convert to owned string