pub struct SqlBridge<C: SqlConnection> { /* private fields */ }Expand description
Unified SQL executor that routes through AST
Implementations
Sourceimpl<C: SqlConnection> SqlBridge<C>
impl<C: SqlConnection> SqlBridge<C>
Sourcepub fn get_scope(&self, name: &str) -> Option<&ScopeDefinition>
pub fn get_scope(&self, name: &str) -> Option<&ScopeDefinition>
Get a scope definition by name.
Sourcepub fn get_table_permissions(
&self,
table: &str,
) -> Option<&StoredTablePermissions>
pub fn get_table_permissions( &self, table: &str, ) -> Option<&StoredTablePermissions>
Get the table permission rules for a table.
Sourcepub fn check_table_permission(
&self,
table: &str,
op: PermissionOp,
) -> SqlResult<()>
pub fn check_table_permission( &self, table: &str, op: PermissionOp, ) -> SqlResult<()>
Check if the given operation is permitted on the table. If no permissions are defined for the table, all operations are allowed. Returns Ok(()) if allowed, Err if denied.
Sourcepub fn execute(&mut self, sql: &str) -> SqlResult<ExecutionResult>
pub fn execute(&mut self, sql: &str) -> SqlResult<ExecutionResult>
Execute a SQL statement
Sourcepub fn execute_with_params(
&mut self,
sql: &str,
params: &[SochValue],
) -> SqlResult<ExecutionResult>
pub fn execute_with_params( &mut self, sql: &str, params: &[SochValue], ) -> SqlResult<ExecutionResult>
Execute a SQL statement with parameters
Sourcepub fn execute_statement(
&mut self,
stmt: &Statement,
params: &[SochValue],
) -> SqlResult<ExecutionResult>
pub fn execute_statement( &mut self, stmt: &Statement, params: &[SochValue], ) -> SqlResult<ExecutionResult>
Execute a parsed statement